==> ejc-sale-impl-3.0.0-20220419.090228-47-sources.jar: com/ejianc/business/sale/bean/SignfreightdetailEntity.java <==
package com.ejianc.business.sale.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 运费签认单子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_sale_signfreightdetail")
public class SignfreightdetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="mid")
    private Long mid; // 主表id

    @TableField(value="consignment_date")
    private Date consignmentDate; // 发货时间
    @TableField(value="consignment_type")
    private Integer consignmentType; // 发货类型
    @TableField(value="confirm_number")
    private BigDecimal confirmNumber; // 实收数量
    @TableField(value="distance")
    private BigDecimal distance; // 运输距离
    @TableField(value="freight")
    private BigDecimal freight; // 运费
    @TableField(value="bill_state")
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="abstracts")
    private String abstracts; // 摘要


    public Long getMid() {
        return mid;
    }

    public void setMid(Long mid) {
        this.mid = mid;
    }

    public Date getConsignmentDate() {
        return consignmentDate;
    }

    public void setConsignmentDate(Date consignmentDate) {
        this.consignmentDate = consignmentDate;
    }
    public Integer getConsignmentType() {
        return consignmentType;
    }

    public void setConsignmentType(Integer consignmentType) {
        this.consignmentType = consignmentType;
    }
    public BigDecimal getConfirmNumber() {
        return confirmNumber;
    }

    public void setConfirmNumber(BigDecimal confirmNumber) {
        this.confirmNumber = confirmNumber;
    }
    public BigDecimal getDistance() {
        return distance;
    }

    public void setDistance(BigDecimal distance) {
        this.distance = distance;
    }
    public BigDecimal getFreight() {
        return freight;
    }

    public void setFreight(BigDecimal freight) {
        this.freight = freight;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getAbstracts() {
        return abstracts;
    }

    public void setAbstracts(String abstracts) {
        this.abstracts = abstracts;
    }
    
}

==> ejc-sale-impl-3.0.0-20220510.091032-98-sources.jar: com/ejianc/business/sale/bean/SignfreightdetailEntity.java <==
package com.ejianc.business.sale.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 运费签认单子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_sale_signfreightdetail")
public class SignfreightdetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="mid")
    private Long mid; // 主表id

    @TableField(value="consignment_date")
    private Date consignmentDate; // 发货时间
    @TableField(value="consignment_type")
    private Integer consignmentType; // 发货类型
    @TableField(value="confirm_number")
    private BigDecimal confirmNumber; // 实收数量
    @TableField(value="distance")
    private BigDecimal distance; // 运输距离
    @TableField(value="freight")
    private BigDecimal freight; // 运费
    @TableField(value="manualshipment_id")
    private Long manualshipmentId; // 发货管理id
    @TableField(value="bill_state")
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="abstracts")
    private String abstracts; // 摘要


    public Long getMid() {
        return mid;
    }

    public void setMid(Long mid) {
        this.mid = mid;
    }

    public Date getConsignmentDate() {
        return consignmentDate;
    }

    public void setConsignmentDate(Date consignmentDate) {
        this.consignmentDate = consignmentDate;
    }
    public Integer getConsignmentType() {
        return consignmentType;
    }

    public void setConsignmentType(Integer consignmentType) {
        this.consignmentType = consignmentType;
    }
    public BigDecimal getConfirmNumber() {
        return confirmNumber;
    }

    public void setConfirmNumber(BigDecimal confirmNumber) {
        this.confirmNumber = confirmNumber;
    }
    public BigDecimal getDistance() {
        return distance;
    }

    public void setDistance(BigDecimal distance) {
        this.distance = distance;
    }
    public BigDecimal getFreight() {
        return freight;
    }

    public void setFreight(BigDecimal freight) {
        this.freight = freight;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getAbstracts() {
        return abstracts;
    }

    public void setAbstracts(String abstracts) {
        this.abstracts = abstracts;
    }

    public Long getManualshipmentId() {
        return manualshipmentId;
    }

    public void setManualshipmentId(Long manualshipmentId) {
        this.manualshipmentId = manualshipmentId;
    }
}
